import { XPromiseError } from './error';
import { XPromiseExecutor } from './rawInfo';
import { XPromiseErrorCodeEnum } from './utils';
import { promiseNoReject, XPromiseCancelError } from './x-fn';

export { XPromiseError, XPromiseErrorCodeEnum };
/** promise拓展 */
export declare class XPromise<T> implements Promise<T> {
    #private;
    /** promise共享 */
    static useSharing: <T_1>(createPromise: () => Promise<T_1>) => {
        applyPromise: () => Promise<T_1>;
    };
    /** promise重试 */
    static retry: <T_1>(createPromise: (retryCount: number) => Promise<T_1>, { maxRetry, canRetry, delay, }: import('./x-fn').XPromiseRetryOptions) => Promise<T_1>;
    /** promise轮询 */
    static polling: <T_1>(createPromise: (retryCount: number) => Promise<T_1>, { maxRetry, delay, }: Omit<import('./x-fn').XPromiseRetryOptions, "maxRetry" | "canRetry"> & Required<Pick<import('./x-fn').XPromiseRetryOptions, "maxRetry">>) => Promise<T_1>;
    /** promise无错 */
    static noReject: typeof promiseNoReject;
    /** 是否是取消/中止错误 */
    static isCancelError: (error: unknown) => error is XPromiseCancelError;
    /** 是否是超时错误 */
    static isTimeoutError: (error: unknown) => error is XPromiseError;
    readonly [Symbol.toStringTag]: string;
    constructor(executorRaw: XPromiseExecutor<T>);
    then<TResult1 = T, TResult2 = never>(onFulfilled?: (value: T) => TResult1 | PromiseLike<TResult1>, onRejected?: (reason: any) => TResult2 | PromiseLike<TResult2>): XPromise<TResult1 | TResult2>;
    catch<TResult = never>(onRejected?: (reason: any) => TResult | PromiseLike<TResult>): XPromise<T | TResult>;
    finally(onFinally?: () => void): XPromise<T>;
    /** 超时设置 */
    timeout: (time: number) => XPromise<T>;
    /** 中止promise */
    abort: (message?: string) => this;
}
